#
# spec file for package ghc-fast-logger
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name fast-logger
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        3.0.1
Release:        lp152.1.4
Summary:        A fast logging system
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-auto-update-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-easy-file-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-unix-compat-devel
BuildRequires:  ghc-unix-time-devel
%if %{with tests}
BuildRequires:  ghc-hspec-devel
%endif

%description
A fast logging system.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Thu Feb 27 2020 psimons@suse.com
- Update fast-logger to version 3.0.1.
  [#]# 3.0.1
  * Creating the `Internal` module.
    [#185](https://github.com/kazu-yamamoto/logger/pull/185)
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri Oct  4 2019 psimons@suse.com
- Update fast-logger to version 3.0.0.
  [#]# 3.0.0
  * Allowing the callback logger to be generic. [#182](https://github.com/kazu-yamamoto/logger/pull/180) This is a BREAKING CHANGE. Users should do:
    1. Importing `LogType'` and related constructors because `LogType` is now a type alias.
    2. Using `{-# LANGUAGE GADTs #-}`, even if you aren't using anything new, any time you try and `case` over values of type `LogType'`.
  [#]# 2.4.17
  * Obtaining a fresh fd from IORef just before writing. [#180](https://github.com/kazu-yamamoto/logger/pull/180)
  [#]# 2.4.16
  * Using strict language extensions.
  [#]# 2.4.15
  * Rescuing GHC 7.8.
* Fri Sep  6 2019 psimons@suse.com
- Update fast-logger to version 2.4.17.
  Upstream has not updated the file "ChangeLog.md" since the last
  release.
* Fri Jun 14 2019 psimons@suse.com
- Update fast-logger to version 2.4.16.
  Upstream has not updated the file "ChangeLog.md" since the last
  release.
* Fri Apr 12 2019 psimons@suse.com
- Update fast-logger to version 2.4.15.
  Upstream has not updated the file "ChangeLog.md" since the last
  release.
* Thu Apr 11 2019 psimons@suse.com
- Update fast-logger to version 2.4.14.
  [#]# 2.4.14
  * Add `ToLogStr` instances for the following types: signed integers, unsigned integers, floating-point numbers. These instances all use decimal encodings. [#177](https://github.com/kazu-yamamoto/logger/pull/177)
* Tue Dec 25 2018 psimons@suse.com
- Update fast-logger to version 2.4.13.
  Upstream has not updated the file "ChangeLog.md" since the last
  release.
* Thu Dec 20 2018 psimons@suse.com
- Update fast-logger to version 2.4.12.
  Upstream has not updated the file "ChangeLog.md" since the last
  release.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update fast-logger to version 2.4.11.
  * Give an explicit definition for (<>) in LogStr's Semigroup instance.
    [#155](https://github.com/kazu-yamamoto/logger/pull/155)
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Feb  5 2017 psimons@suse.com
- Update to version 2.4.10 with cabal2obs.
* Mon Jan 30 2017 psimons@suse.com
- Update to version 2.4.8 with cabal2obs.
* Sat Oct  1 2016 psimons@suse.com
- Update to version 2.4.7 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.4.6 revision 0 with cabal2obs.
- Remove obsolete remove-bytestring-builder.patch.
* Wed Apr 27 2016 mimi.vx@gmail.com
- update to 2.4.6
  * Ensuring that stdio is flushed.
* Tue Apr 26 2016 mimi.vx@gmail.com
- update to 2.4.5
- refreshed remove-bytestring-builder.patch
  * Bringing backward compatibility back
  * New API: newFastLogger and ewTimedFastLogger.
  * LogType and date cache are transferred from wai-logger.
* Wed Apr 13 2016 mimi.vx@gmail.com
- update to 2.4.3
  * Fixing a buf of long log messages
  * Unsupporting GHC 7.4
* Sun Aug 16 2015 mimi.vx@gmail.com
- update to 2.4.1
* Fri Aug  7 2015 mimi.vx@gmail.com
- update to 2.4.0
* Fri Apr 24 2015 mimi.vx@gmail.com
- add remove-bytestring-builder.patch to remove unneded deps
* Fri Apr 24 2015 mimi.vx@gmail.com
- initial commit
